Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGitLab Bot <gitlab-bot@gitlab.com>2020-03-30 18:07:51 +0300
committerGitLab Bot <gitlab-bot@gitlab.com>2020-03-30 18:07:51 +0300
commit4e9acbfba3682c552b3de707c535e6257ef41054 (patch)
tree8b1fd5f89ad3f1be68d8944815b13bb7d498e4a6 /rubocop/migration_helpers.rb
parent506d6dcd7c787ba71a8a53102f3d4fdb6adcfa5e (diff)
Add latest changes from gitlab-org/gitlab@master
Diffstat (limited to 'rubocop/migration_helpers.rb')
-rw-r--r--rubocop/migration_helpers.rb11
1 files changed, 10 insertions, 1 deletions
diff --git a/rubocop/migration_helpers.rb b/rubocop/migration_helpers.rb
index b5edb502d4c..5fa6f8c2a2c 100644
--- a/rubocop/migration_helpers.rb
+++ b/rubocop/migration_helpers.rb
@@ -6,7 +6,7 @@ module RuboCop
plan_limits
].freeze
# Blacklisted table due to:
# - size in GB (>= 10 GB on GitLab.com as of 02/2020)
# - number of records
BLACKLISTED_TABLES = %i[
@@ -44,6 +44,15 @@ module RuboCop
web_hook_logs
].freeze
+ # Blacklisted tables due to:
+ # - number of columns (> 50 on GitLab.com as of 03/2020)
+ # - number of records
+ WIDE_TABLES = %i[
+ users
+ projects
+ ci_builds
+ ].freeze
+
# Returns true if the given node originated from the db/migrate directory.
def in_migration?(node)
dirname(node).end_with?('db/migrate', 'db/geo/migrate') || in_post_deployment_migration?(node)
@@ -6,7 +6,7 @@ module RuboCop
plan_limits
].freeze
- # Blacklisted table due to:
+ # Blacklisted tables due to:
# - size in GB (>= 10 GB on GitLab.com as of 02/2020)
# - number of records